# Generated by Django 3.2.13 on 2022-09-27 01:00

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_protocol_incident", "0013_auto_20220927_0349"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="protocolviolations",
            name="edc_protoco_id_58f1f5_idx",
        ),
        migrations.AddIndex(
            model_name="protocolviolations",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="edc_protoco_id_b2c86f_idx",
            ),
        ),
        migrations.AlterModelTable(
            name="actionsrequired",
            table="edc_protocol_incident_actionsrequired",
        ),
        migrations.AlterModelTable(
            name="protocoldeviationviolation",
            table="edc_protocol_incident_protocoldeviationviolation",
        ),
        migrations.AlterModelTable(
            name="protocolincident",
            table="edc_protocol_incident_protocolincident",
        ),
        migrations.AlterModelTable(
            name="protocolincidents",
            table="edc_protocol_incident_protocolincidents",
        ),
        migrations.AlterModelTable(
            name="protocolviolations",
            table="edc_protocol_incident_protocoldeviationviolations",
        ),
    ]
